summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/dialogs/classpropdlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/dialogs/classpropdlg.h')
-rw-r--r--umbrello/umbrello/dialogs/classpropdlg.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/dialogs/classpropdlg.h b/umbrello/umbrello/dialogs/classpropdlg.h
index afb89f46..8078f372 100644
--- a/umbrello/umbrello/dialogs/classpropdlg.h
+++ b/umbrello/umbrello/dialogs/classpropdlg.h
@@ -45,28 +45,28 @@ public:
/**
* Sets up a ClassPropDlg.
*
* @param tqparent The tqparent of the ClassPropDlg
* @param c The UMLObject to display properties of.
* @param pageNum The page to show first.
* @param assoc Determines whether to display associations
*/
- ClassPropDlg(TQWidget *tqparent, UMLObject *c, int pageNum = 0, bool assoc = false);
+ ClassPropDlg(TQWidget *parent, UMLObject *c, int pageNum = 0, bool assoc = false);
/**
* Sets up a ClassPropDlg.
*
* @param tqparent The tqparent of the ClassPropDlg
* @param o The ObjectWidget to display properties of.
*/
- ClassPropDlg(TQWidget *tqparent, ObjectWidget * o);
+ ClassPropDlg(TQWidget *parent, ObjectWidget * o);
/**
* Sets up a ClassPropDlg.
*
* @param tqparent The tqparent of the ClassPropDlg
* @param o The UMLWidget to display properties of.
*/
- ClassPropDlg(TQWidget *tqparent, UMLWidget * o);
+ ClassPropDlg(TQWidget *parent, UMLWidget * o);
/**
@@ -45,28 +45,28 @@ public:
* Sets up a ClassPropDlg.
*
- * @param tqparent The tqparent of the ClassPropDlg
+ * @param parent The parent of the ClassPropDlg
* @param c The UMLObject to display properties of.
* @param pageNum The page to show first.
@@ -45,28 +45,28 @@ public:
* Sets up a ClassPropDlg.
*
- * @param tqparent The tqparent of the ClassPropDlg
+ * @param parent The parent of the ClassPropDlg
* @param o The ObjectWidget to display properties of.
*/
@@ -45,28 +45,28 @@ public:
* Sets up a ClassPropDlg.
*
- * @param tqparent The tqparent of the ClassPropDlg
+ * @param parent The parent of the ClassPropDlg
* @param o The UMLWidget to display properties of.
*/